@@ -36,6 +36,7 @@
 #include <QMessageBox>
 #include <QFileDialog>
 #include <QPrinter>
+#include <QPrintDialog>
 #include <QClipboard>
 #include <QPixmap>
 #include <QBitmap>
@@ -589,7 +590,7 @@ void Graph3D::updateData(Table* table)
 	int xCol=table->colIndex(xColName);
 	int yCol=table->colIndex(yColName);
 
-	if (name.contains("(Z)",true))
+	if (name.contains("(Z)",Qt::CaseSensitive))
 	{
 		pos=name.indexOf(",",posX);
 		posX=name.indexOf("(",pos);
@@ -901,7 +902,7 @@ void Graph3D::setTickLengths(const QStringList& lst)
 	double majorl,minorl;
 	QStringList tick_length = lst;
 	if (int(lst.count()) > 6)
-		tick_length.remove(tick_length.first());
+		tick_length.removeAll(tick_length.first());
 
 	majorl=tick_length[0].toDouble();
 	minorl=tick_length[1].toDouble();
@@ -1313,7 +1314,7 @@ void Graph3D::updateScales(double xl, double xr, double yl, double yr, double zl
 		QString yColName=name.mid(pos+1,posX-pos-1);
 		int yCol=worksheet->colIndex(yColName);
 
-		if (name.endsWith("(Z)",true))
+		if (name.endsWith("(Z)",Qt::CaseSensitive))
 		{
 			pos=name.indexOf(",",posX);
 			posX=name.indexOf("(",pos);
@@ -1322,7 +1323,7 @@ void Graph3D::updateScales(double xl, double xr, double yl, double yr, double zl
 
 			updateScales(xl, xr, yl, yr, zl, zr, xCol, yCol, zCol);
 		}
-		else if (name.endsWith("(Y)",true))
+		else if (name.endsWith("(Y)",Qt::CaseSensitive))
 			updateScales(xl, xr, yl, yr, zl, zr, xCol, yCol);
 	}
 
@@ -1992,12 +1993,13 @@ void Graph3D::print()
 	printer.setColorMode (QPrinter::Color);
 	printer.setFullPage(false);
 
-	if (printer.setup())
+	QPrintDialog dialog(&printer, this);
+	if (dialog.exec())
 	{
 		if (IO::save (sp,"scidavis.png","PNG"))
 		{
 			QPixmap p;
-			p.load ("scidavis.png","PNG", QPixmap::Color );
+			p.load ("scidavis.png","PNG", Qt::ColorOnly );
 
 			QPainter paint(&printer);
 			paint.drawPixmap(QPoint(0,0),p);
@@ -2008,7 +2010,7 @@ void Graph3D::print()
 		}
 		else
 			QMessageBox::about(0,tr("IO Error"),
-					tr("Could not print: <h4>" + QString(name()) + "</h4>."));
+					tr("Could not print: <h4>") + QString(name()) + "</h4>.");
 	}
 }
 
@@ -2033,7 +2035,7 @@ void Graph3D::exportImage(const QString& fileName, int quality, bool transparent
 
 		QColor background = QColor (Qt::white);
 		QRgb backgroundPixel = background.rgb ();
-		QImage image = pic.convertToImage();
+		QImage image = pic.toImage();
 		for (int y=0; y<image.height(); y++)
 		{
 			for ( int x=0; x<image.width(); x++ )
