@@ -617,7 +617,7 @@ void Matrix::print(const QString& fileName)
 		tr.setWidth(w);
 		tr.setHeight(br.height());
 		header_label = d_view_widget->model()->headerData(i, Qt::Horizontal).toString();
-		p.drawText(tr, Qt::AlignCenter, header_label,-1);
+		p.drawText(tr, Qt::AlignCenter, header_label);
 		right += w;
 		p.drawLine(right, height, right, height+tr.height());
 
@@ -640,7 +640,7 @@ void Matrix::print(const QString& fileName)
 		br.setTopLeft(QPoint(right,height));
 		br.setWidth(vertHeaderWidth);
 		br.setHeight(tr.height());
-		p.drawText(br,Qt::AlignCenter,cell_text,-1);
+		p.drawText(br,Qt::AlignCenter,cell_text);
 		right += vertHeaderWidth;
 		p.drawLine(right, height, right, height+tr.height());
 
@@ -652,7 +652,7 @@ void Matrix::print(const QString& fileName)
 			br.setTopLeft(QPoint(right,height));
 			br.setWidth(w);
 			br.setHeight(tr.height());
-			p.drawText(br, Qt::AlignCenter, cell_text, -1);
+			p.drawText(br, Qt::AlignCenter, cell_text);
 			right += w;
 			p.drawLine(right, height, right, height+tr.height());
 
