@@ -41,10 +41,12 @@
 #include <QMessageBox>
 #include <QDateTime>
 #include <QTextStream>
+#include <QTextCodec>
 #include <QClipboard>
 #include <QApplication>
 #include <QPainter>
 #include <QEvent>
+#include <QCloseEvent>
 #include <QLayout>
 #include <QPrintDialog>
 #include <QLocale>
@@ -182,12 +184,16 @@ void Table::handleRowChange()
 
 void Table::setBackgroundColor(const QColor& col)
 {
-	d_view_widget->setPaletteBackgroundColor( col );
+	QPalette palette;
+	palette.setColor(QPalette::Window, col);
+	d_view_widget->setPalette(palette);
 }
 
 void Table::setTextColor(const QColor& col)
 {
-	d_view_widget->setPaletteForegroundColor(col);
+	QPalette palette;
+	palette.setColor(QPalette::WindowText, col);
+	d_view_widget->setPalette(palette);
 }
 
 void Table::setTextFont(const QFont& fnt)
@@ -197,7 +203,9 @@ void Table::setTextFont(const QFont& fnt)
 
 void Table::setHeaderColor(const QColor& col)
 {
-	d_view_widget->horizontalHeader()->setPaletteForegroundColor (col);
+	QPalette palette;
+	palette.setColor(QPalette::WindowText, col);
+	d_view_widget->horizontalHeader()->setPalette(palette);
 }
 
 void Table::setHeaderFont(const QFont& fnt)
@@ -263,7 +271,7 @@ void Table::print(const QString& fileName)
 		tr.setWidth(w);
 		tr.setHeight(br.height());
 		header_label = d_view_widget->model()->headerData(i, Qt::Horizontal).toString();
-		p.drawText(tr, Qt::AlignCenter, header_label,-1);
+		p.drawText(tr, Qt::AlignCenter, header_label);
 		right += w;
 		p.drawLine(right, height, right, height+tr.height());
 
@@ -286,7 +294,7 @@ void Table::print(const QString& fileName)
 		br.setTopLeft(QPoint(right,height));
 		br.setWidth(vertHeaderWidth);
 		br.setHeight(tr.height());
-		p.drawText(br, Qt::AlignCenter, cell_text, -1);
+		p.drawText(br, Qt::AlignCenter, cell_text);
 		right += vertHeaderWidth;
 		p.drawLine(right, height, right, height+tr.height());
 
@@ -298,7 +306,7 @@ void Table::print(const QString& fileName)
 			br.setTopLeft(QPoint(right,height));
 			br.setWidth(w);
 			br.setHeight(tr.height());
-			p.drawText(br, Qt::AlignCenter, cell_text, -1);
+			p.drawText(br, Qt::AlignCenter, cell_text);
 			right += w;
 			p.drawLine(right, height, right, height+tr.height());
 
@@ -542,7 +550,7 @@ QString Table::saveToString(const QString& geometry)
 void Table::saveToDevice(QIODevice *device, const QString &geometry)
 {
 	QTextStream stream(device);
-	stream.setEncoding(QTextStream::UnicodeUTF8);
+	stream.setCodec(QTextCodec::codecForName("UTF-8"));
 
 	// write start tag
 	stream << "<table>\n";
@@ -564,7 +572,7 @@ void Table::saveToDevice(QIODevice *device, const QString &geometry)
 	if (tmp_file.isOpen()) {
 		tmp_file.seek(0);
 		QTextStream count(&tmp_file);
-		count.setEncoding(QTextStream::UnicodeUTF8);
+		count.setCodec(QTextCodec::codecForName("UTF-8"));
 		while (!count.atEnd())
 			xml_chars += count.read(1024).length();
 	} else
@@ -998,7 +1006,7 @@ bool Table::exportASCII(const QString& fname, const QString& separator,
     {
       QApplication::restoreOverrideCursor();
       QMessageBox::critical(0, tr("ASCII Export Error"),
-                            tr("Could not write to file: <br><h4>"+fname+ "</h4><p>Please verify that you have the right to write to this location!").arg(fname));
+                            tr("Could not write to file: <br><h4>")+fname+tr("</h4><p>Please verify that you have the right to write to this location!"));
       return false;
     }
 
