@@ -39,11 +39,19 @@ if [ -f /etc/os-release ]; then
     . /etc/os-release
 fi
 
-diff Graph1.svg $here/test/renderedImages/"${PRETTY_NAME}"/Graph1.svg
-if test $? -ne 0; then fail; fi
+if [ -z "$TRAVIS" ]; then
+    diff Graph1.png $here/test/renderedImages/Graph1.png
+    if test $? -ne 0; then fail; fi
+fi
 # unfortunately, this test fails, as OpenGL rendering appears to be
 # non-deterministic.
 #diff 3dplot.pdf $here/test/renderedImages/3dplot.pdf
 #if test $? -ne 0; then fail; fi
 
+for i in *.menudat; do
+    diff -q $i $here/test/menuData/$i;
+    if test $? -ne 0; then fail; fi
+done
+
+
 pass
