@@ -20,8 +20,13 @@ private slots:
   void showHelp();
   void chooseHelpFolder();
 
+  void basicWindowTests();
+  void deleteSelectedItems();
+  void showWindowPopupMenu();
+
   void fft();
-  
+
+  void menus();
 public:
   static unsigned numInfos, numWarnings;
 };
